@@ -25,7 +25,8 @@
  * MUST not include config.h
  */
 
-#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+#if (!defined(_MSC_VER) && defined(__cplusplus) && __cplusplus >= 201103L) || \
+	(defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L)
 #  include <stdint.h>
 #elif (defined(__sun) && defined(__SVR4)) || defined(__hpux)
 #  include <inttypes.h>
